@@ -1,4 +1,4 @@
-# $Id: Embed.pm,v 1.2504 1997/06/03 19:33:13 dougm Exp $
+# $Id: Embed.pm,v 1.1 1996/07/21 23:33:03 dougm Exp $
 require 5.002;
 
 package ExtUtils::Embed;
@@ -17,7 +17,7 @@ use vars qw(@ISA @EXPORT $VERSION
 	    );
 use strict;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.2504 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.1 $ =~ /(\d+)\.(\d+)/);
 #for the namespace change
 $Devel::embed::VERSION = "99.99";
 
@@ -35,18 +35,6 @@ sub Version { $VERSION; }
 $Verbose = 0;
 $lib_ext = $Config{lib_ext} || '.a';
 
-sub is_cmd { $0 eq '-e' }
-
-sub my_return {
-    my $val = shift;
-    if(is_cmd) {
-	print $val;
-    }
-    else {
-	return $val;
-    }
-}
-
 sub xsinit { 
     my($file, $std, $mods) = @_;
     my($fh,@mods,%seen);
@@ -126,9 +114,8 @@ sub xsi_body {
     my(@exts) = @_;
     my($pname,@retval,%seen);
     my($dl) = canon('/','DynaLoader');
-    push(@retval, "\tchar *file = __FILE__;\n");
     push(@retval, "\tdXSUB_SYS;\n") if $] > 5.002;
-    push(@retval, "\n");
+    push(@retval, "\tchar *file = __FILE__;\n\n");
 
     foreach $_ (@exts){
         my($pname) = canon('/', $_);
@@ -212,36 +199,35 @@ sub ldopts {
     }
     #print STDERR "\@potential_libs = @potential_libs\n";
 
-    my $libperl = (grep(/^-l\w*perl\w*$/, @link_args))[0] || "-lperl";
-
     my($extralibs, $bsloadlibs, $ldloadlibs, $ld_run_path) =
 	$MM->ext(join ' ', 
-		 $MM->catdir("-L$Config{archlibexp}", "CORE"), " $libperl", 
+		 $MM->catdir("-L$Config{archlib}", "CORE"), " -lperl", 
 		 @potential_libs);
 
     my $ld_or_bs = $bsloadlibs || $ldloadlibs;
     print STDERR "bs: $bsloadlibs ** ld: $ldloadlibs" if $Verbose;
-    my $linkage = "$Config{ccdlflags} $Config{ldflags} @archives $ld_or_bs";
-    print STDERR "ldopts: '$linkage'\n" if $Verbose;
+    my $linkage = "$Config{ldflags} @archives $ld_or_bs";
 
     return $linkage if scalar @_;
-    my_return("$linkage\n");
+    print "$linkage\n";
 }
 
 sub ccflags {
-    my_return(" $Config{ccflags} ");
+   print " $Config{ccflags} ";
 }
 
 sub ccdlflags {
-    my_return(" $Config{ccdlflags} ");
+   print " $Config{ccdlflags} ";
 }
 
 sub perl_inc {
-    my_return(" -I$Config{archlibexp}/CORE ");
+   print " -I $Config{archlib}/CORE ";
 }
 
 sub ccopts {
-   ccflags . perl_inc;
+   ccflags;
+   ccdlflags;
+   perl_inc;
 }
 
 sub canon {
@@ -278,22 +264,20 @@ functions while building your application.
 =head1 @EXPORT
 
 ExtUtils::Embed exports the following functions:
-
-xsinit(), ldopts(), ccopts(), perl_inc(), ccflags(), 
-ccdlflags(), xsi_header(), xsi_protos(), xsi_body()
+ 
+L<xsinit()>, L<ldopts()>, L<ccopts()>, L<perl_inc()>, L<ccflags()>, 
+L<ccdlflags()>, L<xsi_header()>, L<xsi_protos()>, L<xsi_body()>
 
 =head1 FUNCTIONS
 
-=over
-
 =item xsinit()
 
-Generate C/C++ code for the XS initializer function.
+Generate C/C++ code for the XS intializer function.
 
 When invoked as C<`perl -MExtUtils::Embed -e xsinit --`>
 the following options are recognized:
 
-B<-o> E<lt>output filenameE<gt> (Defaults to B<perlxsi.c>)
+B<-o> <output filename> (Defaults to B<perlxsi.c>)
 
 B<-o STDOUT> will print to STDOUT.
 
@@ -316,7 +300,7 @@ B<[@modules]> is an array ref, same as additional arguments mentioned above.
 
 =item Examples
 
-
+ 
  perl -MExtUtils::Embed -e xsinit -- -o xsinit.c Socket
 
 
@@ -355,7 +339,7 @@ B<-std>
 Output arguments for linking the Perl library and any extensions linked
 with the current Perl.
 
-B<-I> E<lt>path1:path2E<gt>
+B<-I> <path1:path2>
 
 Search path for ModuleName.a archives.  
 Default path is B<@INC>.
@@ -370,7 +354,7 @@ we should find B<auto/DBD/Oracle/Oracle.a>
 Keep in mind, you can always supply B</my/own/path/ModuleName.a>
 as an additional linker argument.
 
-B<-->  E<lt>list of linker argsE<gt>
+B<-->  <list of linker args>
 
 Additional linker arguments to be considered.
 
@@ -410,7 +394,7 @@ are picked up from the B<extralibs.ld> file in the same directory.
 
 
  perl -MExtUtils::Embed -e ldopts -- -std Socket
-
+ 
 
 This will do the same as the above example, along with printing additional arguments for linking with the B<Socket> extension.
 
@@ -434,11 +418,11 @@ conflict, the additional arguments will be part of the output.
 
 For including perl header files this function simply prints:
 
- -I$Config{archlibexp}/CORE  
+ -I $Config{archlib}/CORE  
 
 So, rather than having to say:
 
- perl -MConfig -e 'print "-I$Config{archlibexp}/CORE"'
+ perl -MConfig -e 'print "-I $Config{archlib}/CORE"'
 
 Just say:
 
@@ -468,23 +452,27 @@ function to B<boot_ModuleName> for each @modules.
 
 B<xsinit()> uses the xsi_* functions to generate most of it's code.
 
-=back
-
 =head1 EXAMPLES
 
 For examples on how to use B<ExtUtils::Embed> for building C/C++ applications
-with embedded perl, see the eg/ directory and L<perlembed>.
-
+with embedded perl, see the eg/ directory and the I<perlembed> man page.
+ 
 =head1 SEE ALSO
 
-L<perlembed>
+the I<perlembed> man page
 
 =head1 AUTHOR
 
-Doug MacEachern E<lt>F<dougm@osf.org>E<gt>
+Doug MacEachern <dougm@osf.org>
 
-Based on ideas from Tim Bunce E<lt>F<Tim.Bunce@ig.co.uk>E<gt> and
-B<minimod.pl> by Andreas Koenig E<lt>F<k@anna.in-berlin.de>E<gt> and Tim Bunce.
+Based on ideas from Tim Bunce <Tim.Bunce@ig.co.uk> and
+B<minimod.pl> by Andreas Koenig <k@anna.in-berlin.de> and Tim Bunce.
 
 =cut
 
+Bunce <Tim.Bunce@ig.co.uk> and
+B<minimod.pl> by Andreas Koenig <k@anna.in-berlin.de> and Tim Bunce.
+
+=cut
+
+
